[![logo](https://www.hongsnet.net/images/logo.gif)](https://www.hongsnet.net)

# www.hongsnet.net Internal Networking 

> 내부 관리망으로 사용되는 네트워킹 구성요소의 구축내역이며, 여기서 사용되는 기술은 Dynamic Routing Protocol 이다.


## Overview

![dynamic_routing](./images/dynamic_routing.png)


## 구성목적 (**Deprecated**)

- www.hongsnet.net 내부 네트워크 구조를 Dynamic Routing Protocol로 변경한다.
- Dynamic Routing Protocol이 어떻게 동작하는지를 Review 한다.
- Dynamic Routing Protocol로 변경 시 `어떤 서비스의 영향이 발생되는지를 Review` 한다.

> 이 구성은 1G / 100M bps의 스위치로 혼재된 상태이기 때문에 2020년 01월부로 Deprecated 되었다.


## Dynamic Routing Protocol 구성요소

- OSPF 
- EIGRP
- RIP

## Network Switch 구성요소 ( 9 EA )

| NO | Protocol | Role | 역할 | IP | ServiceIP | 모델명 | 비고 |
| ------ | ------ | ------ | ------ | ------ | ------ | ------ | ------ |
| 1 | OSPF | **Area0** | `DR` | 10.10.10.1 | 192.168.200.0/24 | WS-C3750G-48TS-E | 1 Gbps |
| 2 | OSPF | **Area0** | BDR | 10.10.10.2 | N/A | WS-C3560G-48TS-S | 1 Gbps |
| 3 | OSPF | **Area0** | DROTHER | 20.20.20.2 | N/A |WS-C3560G-48TS-S |1 Gbps |
| 4 | OSPF | **Area1** | N/A | 40.40.40.2 | N/A | WS-C3750-48TS-E |100 Mbps |
| 5 | EIGRP | **Area0** | N/A | 30.30.30.2 | 172.24.0.0/16 | WS-C3750-48TS-S |100 Mbps |
| 6 | EIGRP | **Area1** | N/A | 50.50.50.2 | 172.16.0.0/16 | WS-C3550-24-EMI |100 Mbps |
| 7 | EIGRP | Layer2 | N/A | N/A | 172.16.0.0/16 | Cisco WS-C2950T-24 |100 Mbps  |
| 8 | EIGRP | Layer2 | N/A | N/A | 172.16.0.0/16 | Cisco WS-C2950G-12-EI |100 Mbps |
| 9 | RIP | N/A | N/A | N/A | 180.180.180.0/24 | Cisco WS-C3550-24-EMI |100 Mbps |



## Network Review **Key-Point**

* [ ]  `서로 다른 라우팅 프로토콜 간에는 재분배가 발생`되며, 이 설정이 반드시 존재해야 한다.
* [ ]  OSPF 프로토콜의 hello packet은 OSPF 네이버를 형성하고 유지하는데 사용되는 패킷 이다.
* [ ]  OSPF의 `DR`(Designated Router)는 프로토콜의 중심 라우터이며, `멀티액세스 네트워크`(이더넷과 같은 브로드캐스트가 지원되는 네트워크) 기반에서 동작된다. 즉, 위 구성과 같이 L3 Switch로 이루어진 OSPF 네트워크에서는 
* [ ]  OSPF의 `BDR`(Backup DR)는 DR 라우터의 역할을 이어받을 수 있는 라우터 이다. 즉, `DR이 다운`되면, BDR이 DR이되며 BDR은 새로 선출한다. 만약 BDR이 다운되면, BDR을 새로 선출 한다.
* [ ]  OSPF의 `DROTHER`는 DR, BDR이 아닌 라우터를 뜻한다. 그리고 DROTHER 라우터끼리는 라우팅 정보를 교환하지 않는다.
* [ ]  OSPF의 Area1은 논브로드캐스트 네트워크로 구성되어 있으며, 시리얼로 서로 연결되어 있다.
* [ ]  위의 구성과 같이 두 개 이상의 Area로 구성된 환경에서는 그 중 하나는 반드시 에어리어 번호를 0으로 설정해야 한다.



## Network Configuration

> 아래의 내역은 `show running-config` 등과 같이 전체 내역을 표현하지않고, 핵심적인 부분만을 명시한다.


- **OSPF `DR` Switch Configure**

```plaintext
interface GigabitEthernet1/0/49
 description TO-OSPF-TB2-BDR-GigabitEthernet0/49
 no switchport
 ip address 10.10.10.1 255.255.255.252
 ip ospf message-digest-key 1 md5 7 14101A0F1B0A2D20377C656575
 ip ospf network broadcast
!
interface GigabitEthernet1/0/50
 description TO-OSPF-TB3-DROTHER-GigabitEthernet0/49
 no switchport
 ip address 20.20.20.1 255.255.255.252
 ip ospf message-digest-key 1 md5 7 14101A0F1B0A2D20377C656575
 ip ospf network broadcast
!
...중략
interface Vlan192
 ip address 192.168.200.1 255.255.255.0
!
router ospf 1
 router-id 1.1.1.1
 log-adjacency-changes
 area 0 authentication message-digest
 network 10.10.10.1 0.0.0.0 area 0
 network 20.20.20.1 0.0.0.0 area 0
 network 192.168.200.0 0.0.0.255 area 0
!
```

다음의 결과는 통신내역을 출력한 것이다.

```plaintext
OSPF-DR#sh ip route
Codes: C - connected, S - static, R - RIP, M - mobile, B - BGP
       D - EIGRP, EX - EIGRP external, O - OSPF, IA - OSPF inter area
       N1 - OSPF NSSA external type 1, N2 - OSPF NSSA external type 2
       E1 - OSPF external type 1, E2 - OSPF external type 2
       i - IS-IS, su - IS-IS summary, L1 - IS-IS level-1, L2 - IS-IS level-2
       ia - IS-IS inter area, * - candidate default, U - per-user static route
       o - ODR, P - periodic downloaded static route

Gateway of last resort is not set

     50.0.0.0/30 is subnetted, 1 subnets
O E2    50.50.50.0 [110/20] via 20.20.20.2, 7w0d, GigabitEthernet1/0/50
     100.0.0.0/24 is subnetted, 1 subnets
C       100.100.100.0 is directly connected, Vlan100
     20.0.0.0/30 is subnetted, 1 subnets
C       20.20.20.0 is directly connected, GigabitEthernet1/0/50
O E2 172.16.0.0/16 [110/20] via 20.20.20.2, 7w0d, GigabitEthernet1/0/50
O E2 172.24.0.0/16 [110/20] via 10.10.10.2, 7w0d, GigabitEthernet1/0/49
C    192.168.200.0/24 is directly connected, Vlan192
     40.0.0.0/30 is subnetted, 1 subnets
O IA    40.40.40.0 [110/2] via 20.20.20.2, 7w0d, GigabitEthernet1/0/50
     10.0.0.0/30 is subnetted, 1 subnets
C       10.10.10.0 is directly connected, GigabitEthernet1/0/49
     60.0.0.0/30 is subnetted, 1 subnets
O E2    60.60.60.0 [110/20] via 10.10.10.2, 7w0d, GigabitEthernet1/0/49
     30.0.0.0/30 is subnetted, 1 subnets
O E2    30.30.30.0 [110/20] via 10.10.10.2, 7w0d, GigabitEthernet1/0/49
     180.180.0.0/24 is subnetted, 1 subnets
O E2    180.180.180.0 [110/20] via 10.10.10.2, 7w0d, GigabitEthernet1/0/49
```

- **OSPF** `BDR` Switch Configure

```plaintext
interface GigabitEthernet0/49
 description FROM-OSPF-DR-GigabitEthernet1/0/49
 no switchport
 ip address 10.10.10.2 255.255.255.252
 ip ospf message-digest-key 1 md5 7 0708294859071E0E04465D5C53
 ip ospf network broadcast
!
interface GigabitEthernet0/50
 description FROM-EIGRP-TB2-GigabitEthernet1/0/49
 no switchport
 ip address 30.30.30.1 255.255.255.252
!
interface GigabitEthernet0/51
 description FROM-RIP-STORAGE-GigabitEthernet0/1
 no switchport
 ip address 60.60.60.1 255.255.255.252
!
...중략
router eigrp 1
 network 30.30.30.1 0.0.0.0
 redistribute rip metric 1000000 10 255 255 1500
 redistribute ospf  1 metric 1000000 10 255 255 1500
 eigrp router-id 1.1.1.1
!
router ospf 1
 router-id 1.1.2.1
 area 0 authentication message-digest
 redistribute eigrp 1 subnets
 redistribute rip subnets
 network 10.10.10.2 0.0.0.0 area 0
!
router rip
 version 2
 redistribute ospf 1 metric 1
 redistribute eigrp 1 metric 1
 network 60.0.0.0
 no auto-summary
!
```

다음은 라우팅테이블 내역을 출력한 것이다.

```plaintext
OSPF-TB2-BDR#sh ip route
Codes: L - local, C - connected, S - static, R - RIP, M - mobile, B - BGP
       D - EIGRP, EX - EIGRP external, O - OSPF, IA - OSPF inter area
       N1 - OSPF NSSA external type 1, N2 - OSPF NSSA external type 2
       E1 - OSPF external type 1, E2 - OSPF external type 2
       i - IS-IS, su - IS-IS summary, L1 - IS-IS level-1, L2 - IS-IS level-2
       ia - IS-IS inter area, * - candidate default, U - per-user static route
       o - ODR, P - periodic downloaded static route, H - NHRP, l - LISP
       + - replicated route, % - next hop override

Gateway of last resort is not set

      10.0.0.0/8 is variably subnetted, 2 subnets, 2 masks
C        10.10.10.0/30 is directly connected, GigabitEthernet0/49
L        10.10.10.2/32 is directly connected, GigabitEthernet0/49
      20.0.0.0/30 is subnetted, 1 subnets
O        20.20.20.0 [110/2] via 10.10.10.1, 7w0d, GigabitEthernet0/49
      30.0.0.0/8 is variably subnetted, 2 subnets, 2 masks
C        30.30.30.0/30 is directly connected, GigabitEthernet0/50
L        30.30.30.1/32 is directly connected, GigabitEthernet0/50
      40.0.0.0/30 is subnetted, 1 subnets
O IA     40.40.40.0 [110/3] via 10.10.10.1, 7w0d, GigabitEthernet0/49
      50.0.0.0/30 is subnetted, 1 subnets
O E2     50.50.50.0 [110/20] via 10.10.10.1, 7w0d, GigabitEthernet0/49
      60.0.0.0/8 is variably subnetted, 2 subnets, 2 masks
C        60.60.60.0/30 is directly connected, GigabitEthernet0/51
L        60.60.60.1/32 is directly connected, GigabitEthernet0/51
O E2  172.16.0.0/16 [110/20] via 10.10.10.1, 7w0d, GigabitEthernet0/49
D     172.24.0.0/16 [90/3072] via 30.30.30.2, 7w0d, GigabitEthernet0/50
      180.180.0.0/24 is subnetted, 1 subnets
R        180.180.180.0 [120/1] via 60.60.60.2, 00:00:23, GigabitEthernet0/51
      192.168.1.0/24 is variably subnetted, 2 subnets, 2 masks
C        192.168.1.0/24 is directly connected, Vlan192
L        192.168.1.1/32 is directly connected, Vlan192
O     192.168.200.0/24 [110/2] via 10.10.10.1, 7w0d, GigabitEthernet0/49
```


- **OSPF** Area0 `DROTHER` Switch Configure

```plaintext
interface GigabitEthernet0/49
 description TO-OSPF-DR-GigabitEthernet0/50
 no switchport
 ip address 20.20.20.2 255.255.255.252
 ip ospf message-digest-key 1 md5 7 121E0D1305050B0F397F727864
 ip ospf network broadcast
 ip ospf priority 0
!
interface GigabitEthernet0/50
 description TO-OSPF-AREA1-GigabitEthernet0/49
 no switchport
 ip address 40.40.40.1 255.255.255.252
 ip ospf message-digest-key 1 md5 7 0303530F110126475D5D4F5540
 ip ospf network point-to-point
!
...중략
router ospf 1
 router-id 1.1.3.1
 area 0 authentication message-digest
 area 1 authentication message-digest
 network 20.20.20.2 0.0.0.0 area 0
 network 40.40.40.1 0.0.0.0 area 1
!
```

다음은 라우팅테이블 내역을 출력한 것이다.

```plaintext
OSPF-TB3-DROTHER#sh ip route
Codes: L - local, C - connected, S - static, R - RIP, M - mobile, B - BGP
       D - EIGRP, EX - EIGRP external, O - OSPF, IA - OSPF inter area
       N1 - OSPF NSSA external type 1, N2 - OSPF NSSA external type 2
       E1 - OSPF external type 1, E2 - OSPF external type 2
       i - IS-IS, su - IS-IS summary, L1 - IS-IS level-1, L2 - IS-IS level-2
       ia - IS-IS inter area, * - candidate default, U - per-user static route
       o - ODR, P - periodic downloaded static route, H - NHRP, l - LISP
       + - replicated route, % - next hop override

Gateway of last resort is not set

      10.0.0.0/30 is subnetted, 1 subnets
O        10.10.10.0 [110/2] via 20.20.20.1, 7w0d, GigabitEthernet0/49
      20.0.0.0/8 is variably subnetted, 2 subnets, 2 masks
C        20.20.20.0/30 is directly connected, GigabitEthernet0/49
L        20.20.20.2/32 is directly connected, GigabitEthernet0/49
      30.0.0.0/30 is subnetted, 1 subnets
O E2     30.30.30.0 [110/20] via 20.20.20.1, 7w0d, GigabitEthernet0/49
      40.0.0.0/8 is variably subnetted, 2 subnets, 2 masks
C        40.40.40.0/30 is directly connected, GigabitEthernet0/50
L        40.40.40.1/32 is directly connected, GigabitEthernet0/50
      50.0.0.0/30 is subnetted, 1 subnets
O E2     50.50.50.0 [110/20] via 40.40.40.2, 7w0d, GigabitEthernet0/50
      60.0.0.0/30 is subnetted, 1 subnets
O E2     60.60.60.0 [110/20] via 20.20.20.1, 7w0d, GigabitEthernet0/49
O E2  172.16.0.0/16 [110/20] via 40.40.40.2, 7w0d, GigabitEthernet0/50
O E2  172.24.0.0/16 [110/20] via 20.20.20.1, 7w0d, GigabitEthernet0/49
      180.180.0.0/24 is subnetted, 1 subnets
O E2     180.180.180.0 [110/20] via 20.20.20.1, 7w0d, GigabitEthernet0/49
O     192.168.200.0/24 [110/2] via 20.20.20.1, 7w0d, GigabitEthernet0/49
```


- **OSPF Area1 Switch Configure**

```plaintext
interface GigabitEthernet1/0/1
 description FROM-OSPF-TB3-DROTHER-GigabitEthernet0/50
 no switchport
 ip address 40.40.40.2 255.255.255.252
 ip ospf message-digest-key 1 md5 7 14101A0F1B0A2D20377C656575
 ip ospf network point-to-point
 ip ospf priority 0
!
interface GigabitEthernet1/0/2
 description TO-EIGRP-TB3-GigabitEthernet0/1
 no switchport
 ip address 50.50.50.1 255.255.255.252
!
...중략
router eigrp 1
 redistribute ospf 1 metric 1000000 10 255 255 1500
 no auto-summary
 eigrp router-id 1.1.1.1
 network 50.50.50.1 0.0.0.0
!
router ospf 1
 router-id 1.1.4.1
 log-adjacency-changes
 area 1 authentication message-digest
 redistribute eigrp 1 subnets
 network 40.40.40.2 0.0.0.0 area 1
!
```

다음은 라우팅테이블 내역을 출력한 것이다.

```plaintext
TB3-OSPF-AREA1# sh ip route
Codes: C - connected, S - static, R - RIP, M - mobile, B - BGP
       D - EIGRP, EX - EIGRP external, O - OSPF, IA - OSPF inter area
       N1 - OSPF NSSA external type 1, N2 - OSPF NSSA external type 2
       E1 - OSPF external type 1, E2 - OSPF external type 2
       i - IS-IS, su - IS-IS summary, L1 - IS-IS level-1, L2 - IS-IS level-2
       ia - IS-IS inter area, * - candidate default, U - per-user static route
       o - ODR, P - periodic downloaded static route

Gateway of last resort is not set

     50.0.0.0/30 is subnetted, 1 subnets
C       50.50.50.0 is directly connected, GigabitEthernet1/0/2
     20.0.0.0/30 is subnetted, 1 subnets
O IA    20.20.20.0 [110/2] via 40.40.40.1, 7w0d, GigabitEthernet1/0/1
D    172.16.0.0/16 [90/3072] via 50.50.50.2, 7w0d, GigabitEthernet1/0/2
O E2 172.24.0.0/16 [110/20] via 40.40.40.1, 7w0d, GigabitEthernet1/0/1
O IA 192.168.200.0/24 [110/3] via 40.40.40.1, 7w0d, GigabitEthernet1/0/1
     40.0.0.0/30 is subnetted, 1 subnets
C       40.40.40.0 is directly connected, GigabitEthernet1/0/1
     10.0.0.0/30 is subnetted, 1 subnets
O IA    10.10.10.0 [110/3] via 40.40.40.1, 7w0d, GigabitEthernet1/0/1
     60.0.0.0/30 is subnetted, 1 subnets
O E2    60.60.60.0 [110/20] via 40.40.40.1, 7w0d, GigabitEthernet1/0/1
     30.0.0.0/30 is subnetted, 1 subnets
O E2    30.30.30.0 [110/20] via 40.40.40.1, 7w0d, GigabitEthernet1/0/1
     180.180.0.0/24 is subnetted, 1 subnets
O E2    180.180.180.0 [110/20] via 40.40.40.1, 7w0d, GigabitEthernet1/0/1
```


- **OSPF** BDR <-> EIGRP Switch Configure

```plaintext
interface GigabitEthernet1/0/1
 description TO-OSPF-TB2-DROTHER-GigabitEthernet0/50
 no switchport
 ip address 30.30.30.2 255.255.255.252
!
...중략
interface Vlan24
 ip address 172.24.254.1 255.255.0.0
!
!
router eigrp 1
 no auto-summary
 eigrp router-id 1.1.2.1
 eigrp stub connected summary
 network 30.30.30.2 0.0.0.0
 network 172.24.0.0
!
```

다음은 라우팅테이블 내역을 출력한 것이다.

```plaintext
L3-EIGRP-TB2#sh ip route
Codes: C - connected, S - static, R - RIP, M - mobile, B - BGP
       D - EIGRP, EX - EIGRP external, O - OSPF, IA - OSPF inter area
       N1 - OSPF NSSA external type 1, N2 - OSPF NSSA external type 2
       E1 - OSPF external type 1, E2 - OSPF external type 2
       i - IS-IS, su - IS-IS summary, L1 - IS-IS level-1, L2 - IS-IS level-2
       ia - IS-IS inter area, * - candidate default, U - per-user static route
       o - ODR, P - periodic downloaded static route

Gateway of last resort is not set

     50.0.0.0/30 is subnetted, 1 subnets
D EX    50.50.50.0 [170/5376] via 30.30.30.1, 7w0d, GigabitEthernet1/0/1
     20.0.0.0/30 is subnetted, 1 subnets
D EX    20.20.20.0 [170/5376] via 30.30.30.1, 7w0d, GigabitEthernet1/0/1
D EX 172.16.0.0/16 [170/5376] via 30.30.30.1, 7w0d, GigabitEthernet1/0/1
C    172.24.0.0/16 is directly connected, Vlan24
D EX 192.168.200.0/24 [170/5376] via 30.30.30.1, 7w0d, GigabitEthernet1/0/1
     40.0.0.0/30 is subnetted, 1 subnets
D EX    40.40.40.0 [170/5376] via 30.30.30.1, 7w0d, GigabitEthernet1/0/1
     10.0.0.0/30 is subnetted, 1 subnets
D EX    10.10.10.0 [170/5376] via 30.30.30.1, 7w0d, GigabitEthernet1/0/1
     60.0.0.0/30 is subnetted, 1 subnets
D EX    60.60.60.0 [170/5376] via 30.30.30.1, 7w0d, GigabitEthernet1/0/1
     30.0.0.0/30 is subnetted, 1 subnets
C       30.30.30.0 is directly connected, GigabitEthernet1/0/1
     180.180.0.0/24 is subnetted, 1 subnets
D EX    180.180.180.0 [170/5376] via 30.30.30.1, 7w0d, GigabitEthernet1/0/1
```


- **OSPF** Area1 <-> EIGRP Switch Configure

```plaintext
nterface FastEthernet0/23
 description TO-L2_SWITCH-#2-Fa0/3
 switchport trunk encapsulation dot1q
 switchport trunk allowed vlan 16
 switchport mode trunk
 load-interval 30
!
interface FastEthernet0/24
 description TO-L2_SWITCH-#1-Fa0/3
 switchport trunk encapsulation dot1q
 switchport trunk allowed vlan 16
 switchport mode trunk
 load-interval 30
!
interface GigabitEthernet0/1
 description FROM-TB3-OSPF-AREA1-GigabitEthernet1/0/2
 no switchport
 ip address 50.50.50.2 255.255.255.252
!
interface GigabitEthernet0/2
 no switchport
 no ip address
!
interface Vlan1
 no ip address
!
interface Vlan16
 ip address 172.16.254.1 255.255.0.0
!
!
router eigrp 1
 no auto-summary
 eigrp router-id 1.1.2.1
 network 50.50.50.2 0.0.0.0
 network 172.16.0.0
!
```

다음은 라우팅테이블 내역을 출력한 것이다.

```plaintext
L3-TB3-EIGRP# sh ip route
Codes: C - connected, S - static, R - RIP, M - mobile, B - BGP
       D - EIGRP, EX - EIGRP external, O - OSPF, IA - OSPF inter area
       N1 - OSPF NSSA external type 1, N2 - OSPF NSSA external type 2
       E1 - OSPF external type 1, E2 - OSPF external type 2
       i - IS-IS, su - IS-IS summary, L1 - IS-IS level-1, L2 - IS-IS level-2
       ia - IS-IS inter area, * - candidate default, U - per-user static route
       o - ODR, P - periodic downloaded static route

Gateway of last resort is not set

     50.0.0.0/30 is subnetted, 1 subnets
C       50.50.50.0 is directly connected, GigabitEthernet0/1
     20.0.0.0/30 is subnetted, 1 subnets
D EX    20.20.20.0 [170/5376] via 50.50.50.1, 7w0d, GigabitEthernet0/1
C    172.16.0.0/16 is directly connected, Vlan16
D EX 172.24.0.0/16 [170/5376] via 50.50.50.1, 7w0d, GigabitEthernet0/1
D EX 192.168.200.0/24 [170/5376] via 50.50.50.1, 7w0d, GigabitEthernet0/1
     40.0.0.0/30 is subnetted, 1 subnets
D EX    40.40.40.0 [170/5376] via 50.50.50.1, 7w0d, GigabitEthernet0/1
     10.0.0.0/30 is subnetted, 1 subnets
D EX    10.10.10.0 [170/5376] via 50.50.50.1, 7w0d, GigabitEthernet0/1
     60.0.0.0/30 is subnetted, 1 subnets
D EX    60.60.60.0 [170/5376] via 50.50.50.1, 7w0d, GigabitEthernet0/1
     30.0.0.0/30 is subnetted, 1 subnets
D EX    30.30.30.0 [170/5376] via 50.50.50.1, 7w0d, GigabitEthernet0/1
     180.180.0.0/24 is subnetted, 1 subnets
D EX    180.180.180.0 [170/5376] via 50.50.50.1, 7w0d, GigabitEthernet0/1
```

- **OSPF** BDR <-> RIP Switch Configure

```plaintext
interface GigabitEthernet0/1
 description TO-OSPF-TB2-BDR-GigabitEthernet0/51
 no switchport
 ip address 60.60.60.2 255.255.255.252
!
...중략
nterface Vlan180
 ip address 180.180.180.1 255.255.255.0
 load-interval 30
!
interface Vlan192
 no ip address
!
router rip
 version 2
 network 60.0.0.0
 network 180.180.0.0
 no auto-summary
!
```

다음은 라우팅테이블 내역을 출력한 것이다.

```plaintext
L3-RIP-STORAGE#sh ip route
Codes: C - connected, S - static, R - RIP, M - mobile, B - BGP
       D - EIGRP, EX - EIGRP external, O - OSPF, IA - OSPF inter area
       N1 - OSPF NSSA external type 1, N2 - OSPF NSSA external type 2
       E1 - OSPF external type 1, E2 - OSPF external type 2
       i - IS-IS, su - IS-IS summary, L1 - IS-IS level-1, L2 - IS-IS level-2
       ia - IS-IS inter area, * - candidate default, U - per-user static route
       o - ODR, P - periodic downloaded static route

Gateway of last resort is not set

     50.0.0.0/30 is subnetted, 1 subnets
R       50.50.50.0 [120/1] via 60.60.60.1, 00:00:25, GigabitEthernet0/1
     20.0.0.0/30 is subnetted, 1 subnets
R       20.20.20.0 [120/1] via 60.60.60.1, 00:00:25, GigabitEthernet0/1
R    172.16.0.0/16 [120/1] via 60.60.60.1, 00:00:25, GigabitEthernet0/1
R    172.24.0.0/16 [120/1] via 60.60.60.1, 00:00:25, GigabitEthernet0/1
R    192.168.200.0/24 [120/1] via 60.60.60.1, 00:00:25, GigabitEthernet0/1
     40.0.0.0/30 is subnetted, 1 subnets
R       40.40.40.0 [120/1] via 60.60.60.1, 00:00:25, GigabitEthernet0/1
     10.0.0.0/30 is subnetted, 1 subnets
R       10.10.10.0 [120/1] via 60.60.60.1, 00:00:25, GigabitEthernet0/1
     60.0.0.0/30 is subnetted, 1 subnets
C       60.60.60.0 is directly connected, GigabitEthernet0/1
     30.0.0.0/30 is subnetted, 1 subnets
R       30.30.30.0 [120/1] via 60.60.60.1, 00:00:25, GigabitEthernet0/1
     180.180.0.0/24 is subnetted, 1 subnets
C       180.180.180.0 is directly connected, Vlan180
```

- **EIGRP** <-> L2#1 Switch Configure

```plaintext
interface Port-channel1
 switchport access vlan 16
 switchport mode access
 load-interval 30
 flowcontrol send off
!
interface FastEthernet0/1
 description TO-HSRP#2_L2-Fa0/1-SWITCH_TRUNK
 switchport access vlan 16
 switchport mode access
 load-interval 30
 channel-group 1 mode active
!
interface FastEthernet0/2
 description TO-HSRP-ACTIVE_L3-Gi1/0/47
 switchport trunk allowed vlan 16
 switchport mode trunk
 load-interval 30
!
interface FastEthernet0/3
 description TO-HSRP-STANDBY_L3-Fa0/24
 switchport trunk allowed vlan 16
 switchport mode trunk
 load-interval 30
!
...중략
interface FastEthernet0/24
 description TO-HSRP#2-Fa0/12-SWITCH_TRUNK
 switchport access vlan 16
 switchport mode access
 load-interval 30
 channel-group 1 mode active
!
interface GigabitEthernet0/1
!
interface GigabitEthernet0/2
!
interface Vlan1
 no ip address
 no ip route-cache
 shutdown
!
interface Vlan16
 ip address 172.16.254.100 255.255.0.0
 no ip route-cache
!
```

- **EIGRP** <-> L2#1 Switch Configure

```plaintext
!
interface Port-channel1
 switchport access vlan 16
 switchport mode access
 load-interval 30
 flowcontrol send off
!
interface FastEthernet0/1
 description TO-HSRP#1-Fa0/1-SWITCH_TRUNK
 switchport access vlan 16
 switchport mode access
 load-interval 30
 channel-group 1 mode active
!
interface FastEthernet0/2
 description TO-HSRP-ACTIVE-L3_Gi1/0/45
 switchport trunk allowed vlan 16
 switchport mode trunk
 load-interval 30
!
interface FastEthernet0/3
 description TO-HSRP-STANDBY-L3_Fa0/23
 switchport access vlan 16
 switchport trunk allowed vlan 16
 switchport mode trunk
 load-interval 30
!
...중략
!
interface FastEthernet0/12
 description TO-HSRP#1-Fa0/24-SWITCH_TRUNK
 switchport access vlan 16
 switchport mode access
 load-interval 30
 channel-group 1 mode active
!
interface GigabitEthernet0/1
!
interface GigabitEthernet0/2
!
interface Vlan1
 no ip address
 no ip route-cache
 shutdown
!
interface Vlan16
 ip address 172.16.254.200 255.255.0.0
 no ip route-cache
 load-interval 30
!
```

